/*jshint unused:false*/
var dojoConfig = {
	async: true,
	parseOnLoad: false,
	tlmSiblingOfDojo: false,
	isDebug: true,
	packages: [
		'dojo',
		'dijit',
		'dojox',
		'put-selector',
		'xstyle',
		'dgrid',
		'app',
        'dGrowl'
	]
};
